summaryrefslogtreecommitdiff
path: root/contrib/cirrus
diff options
context:
space:
mode:
authorOpenShift Merge Robot <openshift-merge-robot@users.noreply.github.com>2019-05-17 21:49:10 +0200
committerGitHub <noreply@github.com>2019-05-17 21:49:10 +0200
commit00ecbfc1315a62940202574fb45f2ae2f4c48b63 (patch)
tree6a4c8c755c75d3ee215419dc21b8967f41c97be4 /contrib/cirrus
parentba612a098c65f11730e8436cdebe86d3b979ddf4 (diff)
parentcb0d89c56e5a6515a2f79e041a0f7e3937ab087d (diff)
downloadpodman-00ecbfc1315a62940202574fb45f2ae2f4c48b63.tar.gz
podman-00ecbfc1315a62940202574fb45f2ae2f4c48b63.tar.bz2
podman-00ecbfc1315a62940202574fb45f2ae2f4c48b63.zip
Merge pull request #2844 from haircommander/cri-o-update
move to cri-o/cri-o and build with containers/conmon
Diffstat (limited to 'contrib/cirrus')
-rw-r--r--contrib/cirrus/lib.sh12
1 files changed, 6 insertions, 6 deletions
diff --git a/contrib/cirrus/lib.sh b/contrib/cirrus/lib.sh
index f422fe935..a285b133b 100644
--- a/contrib/cirrus/lib.sh
+++ b/contrib/cirrus/lib.sh
@@ -283,16 +283,16 @@ install_buildah() {
ooe.sh sudo make install
}
# Requires $GOPATH and $CRIO_COMMIT to be set
install_conmon(){
- echo "Installing conmon from commit $CRIO_COMMIT"
- req_env_var GOPATH CRIO_COMMIT
- DEST="$GOPATH/src/github.com/kubernetes-sigs/cri-o.git"
+ echo "Installing conmon from commit $CONMON_COMMIT"
+ req_env_var GOPATH CONMON_COMMIT
+ DEST="$GOPATH/src/github.com/containers/conmon.git"
rm -rf "$DEST"
- ooe.sh git clone https://github.com/kubernetes-sigs/cri-o.git "$DEST"
+ ooe.sh git clone https://github.com/containers/conmon.git "$DEST"
cd "$DEST"
ooe.sh git fetch origin --tags
- ooe.sh git checkout -q "$CRIO_COMMIT"
+ ooe.sh git checkout -q "$CONMON_COMMIT"
ooe.sh make
sudo install -D -m 755 bin/conmon /usr/libexec/podman/conmon
}
@@ -283,16 +283,16 @@ install_buildah() {
ooe.sh sudo make install
}
-# Requires $GOPATH and $CRIO_COMMIT to be set
+# Requires $GOPATH and $CONMON_COMMIT to be set
install_conmon(){